@@ -4,6 +4,8 @@ import warnings
 
 from mmcv import Config, DictAction
 
+from mmdet.utils import update_data_root
+
 
 def parse_args():
     parser = argparse.ArgumentParser(description='Print the whole config')
@@ -42,6 +44,10 @@ def main():
     args = parse_args()
 
     cfg = Config.fromfile(args.config)
+
+    # update data root according to MMDET_DATASETS
+    update_data_root(cfg)
+
     if args.cfg_options is not None:
         cfg.merge_from_dict(args.cfg_options)
     print(f'Config:\n{cfg.pretty_text}')
